abacusai.upload_part — AbacusAI documentation

# `abacusai.upload_part`

## Module Contents

### Classes

`UploadPart` | Unique identifiers for a part

class abacusai.upload_part.UploadPart(client, etag=None, md5=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Unique identifiers for a part

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - etag (str) – A unique string for this part.

    - md5 (str) – The MD5 hash of this part.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict